@@ -21,6 +21,8 @@ import proto  # type: ignore
 
 from cloudsdk.google.protobuf import struct_pb2  # type: ignore
 from google.type import latlng_pb2  # type: ignore
+from googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types import api_auth as gca_api_auth
+from googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types import auth
 from googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types import openapi
 
 
@@ -37,6 +39,7 @@ __protobuf__ = proto.module(
         'Retrieval',
         'VertexRagStore',
         'VertexAISearch',
+        'ExternalApi',
         'GoogleSearchRetrieval',
         'EnterpriseWebSearch',
         'DynamicRetrievalConfig',
@@ -376,8 +379,9 @@ class ExecutableCode(proto.Message):
     r"""Code generated by the model that is meant to be executed, and the
     result returned to the model.
 
-    Generated when using the [FunctionDeclaration] tool and
-    [FunctionCallingConfig] mode is set to [Mode.CODE].
+    Generated when using the [CodeExecution] tool, in which the code
+    will be automatically executed, and a corresponding
+    [CodeExecutionResult] will also be generated.
 
     Attributes:
         language (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ExecutableCode.Language):
@@ -413,7 +417,8 @@ class ExecutableCode(proto.Message):
 class CodeExecutionResult(proto.Message):
     r"""Result of executing the [ExecutableCode].
 
-    Always follows a ``part`` containing the [ExecutableCode].
+    Only generated when using the [CodeExecution] tool, and always
+    follows a ``part`` containing the [ExecutableCode].
 
     Attributes:
         outcome (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.CodeExecutionResult.Outcome):
@@ -478,6 +483,11 @@ class Retrieval(proto.Message):
             store. User data is uploaded via the
             VertexRagDataService.
 
+            This field is a member of `oneof`_ ``source``.
+        external_api (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ExternalApi):
+            Use data source powered by external API for
+            grounding.
+
             This field is a member of `oneof`_ ``source``.
         disable_attribution (bool):
             Optional. Deprecated. This option is no
@@ -496,6 +506,12 @@ class Retrieval(proto.Message):
         oneof='source',
         message='VertexRagStore',
     )
+    external_api: 'ExternalApi' = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        oneof='source',
+        message='ExternalApi',
+    )
     disable_attribution: bool = proto.Field(
         proto.BOOL,
         number=3,
@@ -599,8 +615,41 @@ class VertexAISearch(proto.Message):
         filter (str):
             Optional. Filter strings to be passed to the
             search API.
+        data_store_specs (MutableSequence[googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.VertexAISearch.DataStoreSpec]):
+            Specifications that define the specific
+            DataStores to be searched, along with
+            configurations for those data stores. This is
+            only considered for Engines with multiple data
+            stores.
+            It should only be set if engine is used.
     """
 
+    class DataStoreSpec(proto.Message):
+        r"""Define data stores within engine to filter on in a search
+        call and configurations for those data stores. For more
+        information, see
+        https://cloud.google.com/generative-ai-app-builder/docs/reference/rpc/google.cloud.discoveryengine.v1#datastorespec
+
+        Attributes:
+            data_store (str):
+                Full resource name of DataStore, such as Format:
+                ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{dataStore}``
+            filter (str):
+                Optional. Filter specification to filter documents in the
+                data store specified by data_store field. For more
+                information on filtering, see
+                `Filtering <https://cloud.google.com/generative-ai-app-builder/docs/filter-search-metadata>`__
+        """
+
+        data_store: str = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        filter: str = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+
     datastore: str = proto.Field(
         proto.STRING,
         number=1,
@@ -617,6 +666,127 @@ class VertexAISearch(proto.Message):
         proto.STRING,
         number=4,
     )
+    data_store_specs: MutableSequence[DataStoreSpec] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message=DataStoreSpec,
+    )
+
+
+class ExternalApi(proto.Message):
+    r"""Retrieve from data source powered by external API for
+    grounding. The external API is not owned by Google, but need to
+    follow the pre-defined API spec.
+
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+    Attributes:
+        simple_search_params (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ExternalApi.SimpleSearchParams):
+            Parameters for the simple search API.
+
+            This field is a member of `oneof`_ ``params``.
+        elastic_search_params (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ExternalApi.ElasticSearchParams):
+            Parameters for the elastic search API.
+
+            This field is a member of `oneof`_ ``params``.
+        api_spec (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ExternalApi.ApiSpec):
+            The API spec that the external API
+            implements.
+        endpoint (str):
+            The endpoint of the external API. The system
+            will call the API at this endpoint to retrieve
+            the data for grounding. Example:
+            https://acme.com:443/search
+        api_auth (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ApiAuth):
+            The authentication config to access the API. Deprecated.
+            Please use auth_config instead.
+        auth_config (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.AuthConfig):
+            The authentication config to access the API.
+    """
+    class ApiSpec(proto.Enum):
+        r"""The API spec that the external API implements.
+
+        Values:
+            API_SPEC_UNSPECIFIED (0):
+                Unspecified API spec. This value should not
+                be used.
+            SIMPLE_SEARCH (1):
+                Simple search API spec.
+            ELASTIC_SEARCH (2):
+                Elastic search API spec.
+        """
+        API_SPEC_UNSPECIFIED = 0
+        SIMPLE_SEARCH = 1
+        ELASTIC_SEARCH = 2
+
+    class SimpleSearchParams(proto.Message):
+        r"""The search parameters to use for SIMPLE_SEARCH spec.
+        """
+
+    class ElasticSearchParams(proto.Message):
+        r"""The search parameters to use for the ELASTIC_SEARCH spec.
+
+        Attributes:
+            index (str):
+                The ElasticSearch index to use.
+            search_template (str):
+                The ElasticSearch search template to use.
+            num_hits (int):
+                Optional. Number of hits (chunks) to request.
+
+                When specified, it is passed to Elasticsearch as the
+                ``num_hits`` param.
+        """
+
+        index: str = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        search_template: str = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        num_hits: int = proto.Field(
+            proto.INT32,
+            number=6,
+        )
+
+    simple_search_params: SimpleSearchParams = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        oneof='params',
+        message=SimpleSearchParams,
+    )
+    elastic_search_params: ElasticSearchParams = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        oneof='params',
+        message=ElasticSearchParams,
+    )
+    api_spec: ApiSpec = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=ApiSpec,
+    )
+    endpoint: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    api_auth: gca_api_auth.ApiAuth = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=gca_api_auth.ApiAuth,
+    )
+    auth_config: auth.AuthConfig = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=auth.AuthConfig,
+    )
 
 
 class GoogleSearchRetrieval(proto.Message):
