@@ -72,8 +72,8 @@ def _CommonArgs(
     support_watchdog_timer=False,
     support_disk_labels=False,
     support_igmp_query=False,
-    support_reservation_bound=False,
     support_flex_start=False,
+    support_display_device=False,
 ):
   """Adding arguments applicable for creating instance templates."""
   parser.display_info.AddFormat(instance_templates_flags.DEFAULT_LIST_FORMAT)
@@ -128,7 +128,7 @@ def _CommonArgs(
       parser, 'added to', 'instance-template'
   )
   instances_flags.AddProvisioningModelVmArgs(
-      parser, support_reservation_bound=support_reservation_bound,
+      parser,
       support_flex_start=support_flex_start,
   )
   instances_flags.AddInstanceTerminationActionVmArgs(parser)
@@ -210,6 +210,8 @@ The type of reservation for instances created from this template.
     instances_flags.AddGracefulShutdownArgs(parser, is_create=True)
 
   instances_flags.AddTurboModeArgs(parser)
+  if support_display_device:
+    instances_flags.AddDisplayDeviceArg(parser)
 
 
 def _ValidateInstancesFlags(
@@ -321,11 +323,11 @@ def BuildShieldedInstanceConfigMessage(messages, args):
 
 def BuildConfidentialInstanceConfigMessage(
     messages, args, support_confidential_compute_type=False,
-    support_confidential_compute_type_tdx=False):
+    support_confidential_compute_type_tdx=False, support_snp_svsm=False):
   """Builds a confidential instance configuration message."""
   return instance_utils.CreateConfidentialInstanceMessage(
       messages, args, support_confidential_compute_type,
-      support_confidential_compute_type_tdx)
+      support_confidential_compute_type_tdx, support_snp_svsm)
 
 
 def PackageLabels(labels_cls, labels):
@@ -558,6 +560,7 @@ def _RunCreate(
     support_subnet_region=False,
     support_confidential_compute_type=False,
     support_confidential_compute_type_tdx=False,
+    support_snp_svsm=False,
     support_ipv6_reservation=False,
     support_internal_ipv6_reservation=False,
     support_replica_zones=True,
@@ -569,6 +572,7 @@ def _RunCreate(
     support_graceful_shutdown=False,
     support_watchdog_timer=False,
     support_disk_labels=False,
+    support_display_device=False,
 ):
   """Common routine for creating instance template.
 
@@ -600,6 +604,8 @@ def _RunCreate(
         is used.
       support_confidential_compute_type_tdx: Indicate if confidential compute
         type 'TDX' is supported.
+      support_snp_svsm: Indicate whether Secure VM Service Module (SVSM) is
+        supported on AMD SEV-SNP VMs.
       support_ipv6_reservation: Indicate the external IPv6 address is supported.
       support_internal_ipv6_reservation: Indicate the internal IPv6 address is
         supported.
@@ -618,6 +624,7 @@ def _RunCreate(
         supported.
       support_watchdog_timer: Indicate whether the watchdog timer is supported.
       support_disk_labels: Indicate whether disk labels are supported.
+      support_display_device: Indicate whether display device is supported.
 
   Returns:
       A resource object dispatched by display.Displayer().
@@ -743,13 +750,15 @@ def _RunCreate(
       messages=client.messages, args=args
   )
 
-  confidential_instance_config_message = (
-      BuildConfidentialInstanceConfigMessage(
-          messages=client.messages,
-          args=args,
-          support_confidential_compute_type=support_confidential_compute_type,
-          support_confidential_compute_type_tdx=(
-              support_confidential_compute_type_tdx)))
+  confidential_instance_config_message = BuildConfidentialInstanceConfigMessage(
+      messages=client.messages,
+      args=args,
+      support_confidential_compute_type=support_confidential_compute_type,
+      support_confidential_compute_type_tdx=(
+          support_confidential_compute_type_tdx
+      ),
+      support_snp_svsm=support_snp_svsm,
+  )
 
   node_affinities = sole_tenancy_util.GetSchedulingNodeAffinityListFromArgs(
       args, client.messages
@@ -1064,6 +1073,11 @@ def _RunCreate(
       )
     instance_template.properties.partnerMetadata = partner_metadata_message
 
+  if support_display_device and args.IsSpecified('enable_display_device'):
+    instance_template.properties.displayDevice = (
+        client.messages.DisplayDevice(enableDisplay=args.enable_display_device)
+    )
+
   request = client.messages.ComputeInstanceTemplatesInsertRequest(
       instanceTemplate=instance_template, project=instance_template_ref.project
   )
@@ -1128,6 +1142,7 @@ class Create(base.CreateCommand):
   _support_subnet_region = False
   _support_confidential_compute_type = True
   _support_confidential_compute_type_tdx = True
+  _support_snp_svsm = False
   _support_replica_zones = True
   _support_local_ssd_size = True
   _support_network_queue_count = True
@@ -1142,9 +1157,9 @@ class Create(base.CreateCommand):
   _support_disk_labels = False
   _support_ipv6_only = True
   _support_igmp_query = False
-  _support_reservation_bound = False
   _support_host_error_timeout_seconds = True
   _support_flex_start = False
+  _support_display_device = False
 
   @classmethod
   def Args(cls, parser):
@@ -1171,9 +1186,9 @@ class Create(base.CreateCommand):
         support_disk_labels=cls._support_disk_labels,
         support_ipv6_only=cls._support_ipv6_only,
         support_igmp_query=cls._support_igmp_query,
-        support_reservation_bound=cls._support_reservation_bound,
         support_host_error_timeout_seconds=cls._support_host_error_timeout_seconds,
         support_flex_start=cls._support_flex_start,
+        support_display_device=cls._support_display_device,
     )
     instances_flags.AddMinCpuPlatformArgs(parser, base.ReleaseTrack.GA)
     instances_flags.AddPrivateIpv6GoogleAccessArgForTemplate(
@@ -1181,10 +1196,10 @@ class Create(base.CreateCommand):
     )
     instances_flags.AddConfidentialComputeArgs(
         parser,
-        support_confidential_compute_type=cls
-        ._support_confidential_compute_type,
-        support_confidential_compute_type_tdx=cls
-        ._support_confidential_compute_type_tdx)
+        support_confidential_compute_type=cls._support_confidential_compute_type,
+        support_confidential_compute_type_tdx=cls._support_confidential_compute_type_tdx,
+        support_snp_svsm=cls._support_snp_svsm,
+    )
     instance_templates_flags.AddKeyRevocationActionTypeArgs(parser)
     instances_flags.AddPerformanceMonitoringUnitArgs(parser)
 
@@ -1213,6 +1228,7 @@ class Create(base.CreateCommand):
         support_subnet_region=self._support_subnet_region,
         support_confidential_compute_type=self._support_confidential_compute_type,
         support_confidential_compute_type_tdx=self._support_confidential_compute_type_tdx,
+        support_snp_svsm=self._support_snp_svsm,
         support_replica_zones=self._support_replica_zones,
         support_performance_monitoring_unit=self._support_performance_monitoring_unit,
         support_internal_ipv6_reservation=self._support_internal_ipv6_reservation,
@@ -1223,6 +1239,7 @@ class Create(base.CreateCommand):
         support_watchdog_timer=self._support_watchdog_timer,
         support_disk_labels=self._support_disk_labels,
         support_host_error_timeout_seconds=self._support_host_error_timeout_seconds,
+        support_display_device=self._support_display_device,
     )
 
 
@@ -1254,6 +1271,7 @@ class CreateBeta(Create):
   _support_subnet_region = False
   _support_confidential_compute_type = True
   _support_confidential_compute_type_tdx = True
+  _support_snp_svsm = False
   _support_replica_zones = True
   _support_local_ssd_recovery_timeout = True
   _support_local_ssd_size = True
@@ -1269,8 +1287,8 @@ class CreateBeta(Create):
   _support_disk_labels = True
   _support_ipv6_only = True
   _support_igmp_query = False
-  _support_reservation_bound = True
-  _support_flex_start = False
+  _support_flex_start = True
+  _support_display_device = True
 
   @classmethod
   def Args(cls, parser):
@@ -1298,8 +1316,8 @@ class CreateBeta(Create):
         support_disk_labels=cls._support_disk_labels,
         support_ipv6_only=cls._support_ipv6_only,
         support_igmp_query=cls._support_igmp_query,
-        support_reservation_bound=cls._support_reservation_bound,
         support_flex_start=cls._support_flex_start,
+        support_display_device=cls._support_display_device,
     )
     instances_flags.AddMinCpuPlatformArgs(parser, base.ReleaseTrack.BETA)
     instances_flags.AddPrivateIpv6GoogleAccessArgForTemplate(
@@ -1310,7 +1328,7 @@ class CreateBeta(Create):
         support_confidential_compute_type=cls
         ._support_confidential_compute_type,
         support_confidential_compute_type_tdx=cls
-        ._support_confidential_compute_type_tdx)
+        ._support_confidential_compute_type_tdx, support_snp_svsm=cls._support_snp_svsm)
     instances_flags.AddPostKeyRevocationActionTypeArgs(parser)
     instance_templates_flags.AddKeyRevocationActionTypeArgs(parser)
     instances_flags.AddPerformanceMonitoringUnitArgs(parser)
@@ -1342,6 +1360,7 @@ class CreateBeta(Create):
         support_subnet_region=self._support_subnet_region,
         support_confidential_compute_type=self._support_confidential_compute_type,
         support_confidential_compute_type_tdx=self._support_confidential_compute_type_tdx,
+        support_snp_svsm=self._support_snp_svsm,
         support_replica_zones=self._support_replica_zones,
         support_local_ssd_recovery_timeout=self._support_local_ssd_recovery_timeout,
         support_performance_monitoring_unit=self._support_performance_monitoring_unit,
@@ -1352,6 +1371,7 @@ class CreateBeta(Create):
         support_graceful_shutdown=self._support_graceful_shutdown,
         support_watchdog_timer=self._support_watchdog_timer,
         support_disk_labels=self._support_disk_labels,
+        support_display_device=self._support_display_device,
     )
 
 
@@ -1383,6 +1403,7 @@ class CreateAlpha(Create):
   _support_subnet_region = True
   _support_confidential_compute_type = True
   _support_confidential_compute_type_tdx = True
+  _support_snp_svsm = True
   _support_replica_zones = True
   _support_local_ssd_recovery_timeout = True
   _support_network_queue_count = True
@@ -1398,8 +1419,8 @@ class CreateAlpha(Create):
   _support_watchdog_timer = True
   _support_disk_labels = True
   _support_igmp_query = True
-  _support_reservation_bound = True
   _support_flex_start = True
+  _support_display_device = True
 
   @classmethod
   def Args(cls, parser):
@@ -1428,17 +1449,17 @@ class CreateAlpha(Create):
         support_watchdog_timer=cls._support_watchdog_timer,
         support_disk_labels=cls._support_disk_labels,
         support_igmp_query=cls._support_igmp_query,
-        support_reservation_bound=cls._support_reservation_bound,
         support_flex_start=cls._support_flex_start,
+        support_display_device=cls._support_display_device,
     )
     instances_flags.AddLocalNvdimmArgs(parser)
     instances_flags.AddMinCpuPlatformArgs(parser, base.ReleaseTrack.ALPHA)
     instances_flags.AddConfidentialComputeArgs(
         parser,
-        support_confidential_compute_type=cls
-        ._support_confidential_compute_type,
-        support_confidential_compute_type_tdx=cls
-        ._support_confidential_compute_type_tdx)
+        support_confidential_compute_type=cls._support_confidential_compute_type,
+        support_confidential_compute_type_tdx=cls._support_confidential_compute_type_tdx,
+        support_snp_svsm=cls._support_snp_svsm,
+    )
     instances_flags.AddPrivateIpv6GoogleAccessArgForTemplate(
         parser, utils.COMPUTE_ALPHA_API_VERSION
     )
@@ -1475,6 +1496,7 @@ class CreateAlpha(Create):
         support_subnet_region=self._support_subnet_region,
         support_confidential_compute_type=self._support_confidential_compute_type,
         support_confidential_compute_type_tdx=self._support_confidential_compute_type_tdx,
+        support_snp_svsm=self._support_snp_svsm,
         support_replica_zones=self._support_replica_zones,
         support_local_ssd_recovery_timeout=self._support_local_ssd_recovery_timeout,
         support_performance_monitoring_unit=self._support_performance_monitoring_unit,
@@ -1485,6 +1507,7 @@ class CreateAlpha(Create):
         support_graceful_shutdown=self._support_graceful_shutdown,
         support_watchdog_timer=self._support_watchdog_timer,
         support_disk_labels=self._support_disk_labels,
+        support_display_device=self._support_display_device,
     )
 
 
